@@ -21,7 +21,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 /* This file consists almost entirely of code taken from the GNU debugger
    (gdb) version 4.17, from file gdb/remote.c.  Additions by me (brg) have
@@ -655,6 +655,10 @@ void getpkt (char *buf, int forever)
 		puts_filtered ("Timed out.\n");
 	      goto retry;
 	    }
+	  if (c == SERIAL_EOF)
+	    {
+	      return;
+	    }
 	}
       while (c != '$');
 
